/****************************************************************

			     MainDoor 1.00

                   SETUP.MD

       (c) 1991-1995 Francisco Sedano


Unless otherwise indicated, strings are C-Style, that is,
ASCIIZ, NULL terminated

To compute the CRC use from offset 0 in SETUP.MD to offset

sizeof(CONFIG_FILE)-sizeof(CONFIG_FILE.CRC), that is, skip 5 last bytes

*****************************************************************

To locate SETUP.MD do the following:

a) Check MD environment variable.
    If defined, it will give SETUP.MD path.
    If not, use MD's directory

b) Check TASK environment variable.
    If defined, use it to create config file names. If task=1, these
    names will be EVENTS01.MD and MDMCFG01.MD.

    If not defined, they will be EVENTS.MD and MDMCFG.MD

********************************************************************/

#ifndef __CFGH
#define __CFGH


/*** EVENTxx.MD ***/
#include "..\common\events.h"

/*** PASSWORD.MD ***/
#include "..\common\password.h"

/*** MDMCFGxx.MD ***/
#include "..\common\modem.h"


/*** Today.md file ***/
typedef struct
{
    unsigned int    Date;
    unsigned int    TotalBBS;
    unsigned int    TotalMail;
    unsigned long   TotalKbOut,
                    TotalKbIn,
                    FreqKb;
	}TODAY,*TODAYPTR;


/*** Lastin.md and Lastout.md ***/
typedef struct
{
	char SystemName	[54];
	char SysopName	[54];
    char City       [54];
    char NetAddr    [35];
    time_t          Time;
    uchar Success;
	uchar Signature;
    }LAST, *LASTPTR;


/****** Misc. definitions **********/

enum _CanFreq {
     CANFREQ_FIRST,     /* Reserved */
     CANFREQ_ALL,       /* All system can FREQ */
     CANFREQ_NONE,      /* No FREQ allowed */
     CANFREQ_VIP,       /* Only VIP Freq */
     CANFREQ_LISTED,    /* Only LISTED systems */
     CANFREQ_SECURE,    /* Only SECURE sessions */
     CANFREQ_LAST       /* Reserved */
	 };


/* Check FINGERPRINT before doing anything else. It must be
equal to this:
*/
#define CFG_THISVERSION "010795"


/* Internal use only */
#define CAP_EDITOR      0x01
#define CAP_TERMINAL	0x02
#define CAP_CFG         0x04


/* Swap enabled/disabled */
#define CFG_SWAP        0x01
#define CFG_NOSWAP      0x00

/* Definitions of function keys settings */

#define CFG_K_AUTO      0x01    /* Internal use */
#define CFG_K_RESCAN    0x02    /* Internal use */
#define CFG_K_NEWSESS   0x04    /* Separate session */
#define CFG_K_FS        0x08    /* Full screen */


/* Screensaver settings */

#define SCR_BLANK       0x01
#define SCR_WINDOW      0x02

/**** Modem strings *******/

#define USR_DEF_NORMAL  0x01
#define USR_DEF_EXIT    0x02
#define USR_DEF_HANG    0x03
#define USR_DEF_FAX     0x04
/***********************************/

/*** LOG options (LogFlags) ***/

#define LOG_INFO	0x0001		// -
#define LOG_MODEM	0x0002		// =
#define LOG_MAJOR	0x0004		// +
#define LOG_REMOTE	0x0008		// :
#define LOG_TRX		0x0010		// *
#define LOG_MONEY	0x0020		// $
#define LOG_ERROR	0x0040		// ?
#define LOG_ALL     0x8000      // All


#define _MAXEVENTS	26

/** User defined keys **/

typedef struct _userkey
{
	char
        Title[41],
		String[41],
		Flags;
	unsigned short
        Reserved;
} USERKEY;


/** Setup.md file **/


typedef struct
	{
	char
        fingerprint[8],         /*      "FSedano"        */
        version[7],             // CFG_THISVERSION
        banner[128],            /* Informational string */
        Adress[21][25],
        Reserv1[25],
        kbdpassword[18],        /* Keylock password */
        Name[60],               /* General > Name */
        City[50],               /* General > Site */
        Phone[30],              /* General > Phone */
        Flags[60],              /* General > Flags */
        filespath[50],          /* Inbound Path */
        pktspath[50],           /* Temp (PKT) path */
        netmailpath[50],        /* Netmail path */
        mainpath[50],           /* System path */
        logpath[50],            /* Log file */
        flagpath[50],           /* FLAG path. If empty, use system */
        onfile[50],             /* Name of the file sent when loading BBS */
        offfile[50],            /* Name of the file sent if no BBS av.*/
        Reserved2[50],
        nodepath[50],           /* NODELIST path */
        swappath[50],           /* Swap path (DOS) */
        msgpath[50],            /* Msg base path */
        vip_users_passwd[11],   /* VIP user password */

       /* File Request */

       DirList[50],             /* file containing directories to search in */
       SecList[50],             /* Same, but for SECURE sessions */
       Alias [50],              /* File containing MAGICS (ALIAS) names */
       SecAlias[50],            /* Same, but for SECURE sessions */
       FailedFreqMsg[50],       /* Message to append on failed request */
       FreqMode,                /*  File request mode. One of:
                                    CANFREQ_ALL,
                                    CANFREQ_NONE,
                                    CANFREQ_VIP,
                                    CANFREQ_LISTED,
                                    CANFREQ_SECURE
                                 */
        vip_freq_file[50];      /* VIP address file */
unsigned short
        FreqMaxFiles,           /* Max files to send in 1 file request */
        FreqMaxTime,            /* Max time (min) to spend */
        FreqMaxSize;            /* Max size (kb) to send in 1 freq */
unsigned long
        FreqMinSpeed;           /* Minimum BPS */
unsigned short
    Com1Base,                   /* Base address for COM1 (DOS) */
	Com2Base,
	Com3Base,
	Com4Base;
char
    Com1IRQ,                    /* IRQ (NOT INT!) for COM1 */
	Com2IRQ,
	Com3IRQ,
	Com4IRQ;
short
    RingTimes;                  /* Answer at ring # */
char
        Reserv3[36];
char
        FreqReqPrEnabled,       /* 1 if FREQ Processor enabled */
        FreqReqPrSwap,          /* 1 if SWAP enabled on call to FREQ processor (DOS) */

/* User names */
        UserName[10][45],
        UserPwd [10][10];

	short
        ErrEchoMail,            /* Err level to exit with upon ECHOMAIL rcvd */
        ErrNetMail,             /* Err level to exit with upon NETMAIL  rcvd */
        ErrNetEchoMail,         /* Err level to exit with upon ECHO & NET    */
        Err1200,                /* Err level if human caller @ 1200 bps */
		Err2400,
		Err4800,
		Err7200,
		Err9600,
		Err12000,
		Err14400,
		Err16800,
		Err19200,
		Err38400,
        ErrDef,                 /* Err level if human caller @ other speed */
        Reserved4[10],
        country_code,           /* Country code */
        Reserved5[5],           /* DONT WRITE HERE */
        ZMODEM_ZAP,             /* Allow > 1024 Blocks in zmodem */
        ZMODEM_RETRYS,          /* max # of retries */
        ZMODEM_ERRORS;          /* max # of errors */

        ModemCtrl   Modem;      /* Modem strings stuff */

	short
        ModemEnabled,
        EMSI,                   /* 1 if EMSI available */
        YOOHOO,                 /* 1 if YOOHOO available */
        FTS_001,                /* 1 if FTS001 available */
        Reserved6,
        XMS,                    /* 1 if XMS must be used for swapping */
        EMS,                    /* 1 if EMS must be used for swapping */
        EXTd,                   /* 1 if EXTd memory must be used for swapping */
        Reserved7,
        SwapEnabled,            /* 1 if SWAP is enabled */
        UnknownSessions,        /* 1 if sessions w/ unknown systems allowed */
        NoPasswdSessions,       /* 1 if unsecure sessions allowed */
        KillEmpty,              /* 1 if empty msgs must be killed */
        BbsEnabled,             /* 1 if there is BBS */
        retrys_busy,            /* max # of retr. in case of BUSY */
        retrys_hand,
        secs_bbs;               /* Secs before passing to BBS */


        struct __evento         OldEvent[26];      /* UNUSED */
        USERKEY                 UsrKeys[48];        /* User defined keys */

 /*** Colours ***/
 short
 ColorHourBanner     ,
 ColorDateBanner    ,
 ColorTrans          ,
 ColorBorder          ,
 ColorHeader     ,
 ColorDarkBar    ,
 ColorLigthBar       ,
 ColorText          ,
 ColorLogHour        ,
 ColorWindow1       ,
 ColorWindow2       ,
 ColorWindow3       ,
 ColorWindow4       ,
 ColorWindow5       ,
 ColorWindow6       ,
 ColorWindowF       ,
 ColorIntense        ,
 ColorDialog        ,
 ColorInfo           ,
 ColorShell          ,
 ColorError          ,
 ColorMenu           ,
 ColorInvMenu        ,
 ColorSession        ,
 ColorTime         ,
 ColorFiles          ,
 ColorSetFlag,
 ColorResetFlag,
 ColorFlashFlag,
 ColorTimeLast;

 short
    Reserved8[6],
    SCRSav,                 /* 1 if screen saver active */
    SCRSavTime,             /* Secs to activate screen saver */
    SCRSavMode,             /* Scr saver mode */
    SCRScroll,              /* Main window scroll */
    SpeedKbd,               /* 1 if speedkeys */
    Reserved9,
    Reserved10,
    CreateNameIndex,        /* 1 if must create a name index */
    Sounds,                 /* 1 if must do sounds */
    Shadow;                 /* 1 if the windows have shadows */
char
    FreqProgram[81],        /* File Request Processor command line */
    ProtFilesPath[51];      /* Inbound path to SECURE sessions */

short
    UseHourBBS,             /* Use open-hours nodelist flag */
    DaysPackHist;           /* Max days to keep inb/outb history */

    char bbsname[41];       /* BBS name */
    short ForcePoll;        /* SECURE sessions */
    short OrderNames;       /* 1 if MDNC is sorting by first names */
    char Domain[21][15];    /* Domain names */
    short LogFlags;         /* Things to log */
    char Reserved11[626];

    char
         CRC[5];            /* CRC16 in ASCII uppercase. For example,
                                for 0xF0CA this field would be "F0CA"
                                NULL terminated.
                            */

    } CONFIG_FILE, *CONFIG_FILEPTR;

#endif
